
[![License: MIT](https://img.shields.io/badge/license-MIT-brightgreen?style=for-the-badge)](https://opensource.org/licenses/MIT)

# aw11

*aw11* is a collection of utilities for formatting and linting code and config
files in a way that the author is partial.

### installation

`pip install aw11`

### utilities

#### clean
`aw11-clean --help`

#### git-pre-commit.sh
Add as a part of your pre-commit script to automatically clean changes to be
committed.
